pub struct Stream { /* private fields */ }Expand description
Wrapper around a CUDA stream.
A CUDA stream is a linear sequence of execution that belongs to a specific
device, independent from other streams. See the documentation for
torch.cuda.Stream for more details.
Implementations
Sourceimpl Stream
impl Stream
Sourcepub fn clone_ref(&self, py: Python<'_>) -> Self
pub fn clone_ref(&self, py: Python<'_>) -> Self
Clone this stream reference. Requires holding the GIL.
Sourcepub fn new_with_device(device: CudaDevice) -> Self
pub fn new_with_device(device: CudaDevice) -> Self
Create a new stream on the specified device, at priority 0.
Sourcepub fn get_current_stream() -> Self
pub fn get_current_stream() -> Self
Get the current stream on the current device.
Sourcepub fn get_current_stream_on_device(device: CudaDevice) -> Self
pub fn get_current_stream_on_device(device: CudaDevice) -> Self
Get the current stream on the specified device.
Sourcepub fn set_current_stream(stream: &Stream)
pub fn set_current_stream(stream: &Stream)
Set the provided stream as the current stream. Also sets the current device to be the same as the stream’s device.
Sourcepub fn wait_event(&self, event: &mut Event)
pub fn wait_event(&self, event: &mut Event)
Make all future work submitted to this stream wait for an event.
Sourcepub fn wait_stream(&self, stream: &Stream)
pub fn wait_stream(&self, stream: &Stream)
Synchronize with another stream.
All future work submitted to this stream will wait until all kernels submitted to a given stream at the time of call entry complete.
Sourcepub fn record_event(&self, event: Option<Event>) -> Event
pub fn record_event(&self, event: Option<Event>) -> Event
Record an event on this stream. If no event is provided one will be created.
Sourcepub fn synchronize(&self)
pub fn synchronize(&self)
Wait for all kernels in this stream to complete.
pub fn stream(&self) -> cudaStream_t